# BingAI (ChatGPT)

## Bing AI API for ChatGPT

### Installation

```
pip install bingai --upgrade
```

### Usage
```
from bingai import ChatbotSession
session = ChatbotSession(email, password)
session.run()
```
